@@ -20,44 +20,28 @@
 |![Typescript Logo](https://docs.aws.amazon.com/cdk/api/latest/img/typescript32.png) Typescript|`@aws-solutions-constructs/aws-kinesis-streams-kinesis-firehose-s3`|
 |![Java Logo](https://docs.aws.amazon.com/cdk/api/latest/img/java32.png) Java|`software.amazon.awsconstructs.services.kinesisstreamskinesisfirehoses3`|
 
-## Overview
-
 This AWS Solutions Construct implements an Amazon Kinesis Data Stream (KDS) connected to Amazon Kinesis Data Firehose (KDF) delivery stream connected to an Amazon S3 bucket.
 
-Here is a minimal deployable pattern definition:
+Here is a minimal deployable pattern definition in Typescript:
 
-Typescript
-
-```python
-import { Construct } from 'constructs';
-import { Stack, StackProps } from 'aws-cdk-lib';
+```javascript
 import { KinesisStreamsToKinesisFirehoseToS3 } from '@aws-solutions-constructs/aws-kinesisstreams-kinesisfirehose-s3';
 
 new KinesisStreamsToKinesisFirehoseToS3(this, 'test-stream-firehose-s3', {});
+
 ```
 
-Python
+## Initializer
 
-```python
-from aws_solutions_constructs.aws_kinesis_streams_kinesis_firehose_s3 import KinesisStreamsToKinesisFirehoseToS3
-from aws_cdk import Stack
-from constructs import Construct
-
-KinesisStreamsToKinesisFirehoseToS3(self, 'test_stream_firehose_s3')
+```text
+new KinesisStreamsToKinesisFirehoseToS3(scope: Construct, id: string, props: KinesisStreamsToKinesisFirehoseToS3Props);
 ```
 
-Java
+*Parameters*
 
-```java
-import software.constructs.Construct;
-
-import software.amazon.awscdk.Stack;
-import software.amazon.awscdk.StackProps;
-import software.amazon.awsconstructs.services.kinesisstreamskinesisfirehoses3.*;
-
-new KinesisStreamsToKinesisFirehoseToS3(this, "test_stream_firehose_s3", new KinesisStreamsToKinesisFirehoseToS3Props.Builder()
-        .build());
-```
+* scope [`Construct`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_core.Construct.html)
+* id `string`
+* props [`KinesisStreamsToKinesisFirehoseToS3Props`](#pattern-construct-props)
 
 ## Pattern Construct Props
 
@@ -120,7 +104,7 @@ Out of the box implementation of the Construct without any override will set the
 ---
 
 
-© Copyright 2022 Amazon.com, Inc. or its affiliates. All Rights Reserved.
+© Copyright 2021 Amazon.com, Inc. or its affiliates. All Rights Reserved.
 '''
 import abc
 import builtins
@@ -132,8 +116,6 @@ import jsii
 import publication
 import typing_extensions
 
-from typeguard import check_type
-
 from ._jsii import *
 
 import aws_cdk.aws_cloudwatch
@@ -142,28 +124,28 @@ import aws_cdk.aws_kinesis
 import aws_cdk.aws_kinesisfirehose
 import aws_cdk.aws_logs
 import aws_cdk.aws_s3
-import aws_cdk.core
+import constructs
 
 
 class KinesisStreamsToKinesisFirehoseToS3(
-    aws_cdk.core.Construct,
+    constructs.Construct,
     metaclass=jsii.JSIIMeta,
     jsii_type="@aws-solutions-constructs/aws-kinesisstreams-kinesisfirehose-s3.KinesisStreamsToKinesisFirehoseToS3",
 ):
     def __init__(
         self,
-        scope: aws_cdk.core.Construct,
+        scope: constructs.Construct,
         id: builtins.str,
         *,
-        bucket_props: typing.Optional[typing.Union[aws_cdk.aws_s3.BucketProps, typing.Dict[str, typing.Any]]] = None,
+        bucket_props: typing.Optional[aws_cdk.aws_s3.BucketProps] = None,
         create_cloud_watch_alarms: typing.Optional[builtins.bool] = None,
         existing_bucket_obj: typing.Optional[aws_cdk.aws_s3.IBucket] = None,
         existing_logging_bucket_obj: typing.Optional[aws_cdk.aws_s3.IBucket] = None,
         existing_stream_obj: typing.Optional[aws_cdk.aws_kinesis.Stream] = None,
         kinesis_firehose_props: typing.Any = None,
-        kinesis_stream_props: typing.Optional[typing.Union[aws_cdk.aws_kinesis.StreamProps, typing.Dict[str, typing.Any]]] = None,
-        logging_bucket_props: typing.Optional[typing.Union[aws_cdk.aws_s3.BucketProps, typing.Dict[str, typing.Any]]] = None,
-        log_group_props: typing.Optional[typing.Union[aws_cdk.aws_logs.LogGroupProps, typing.Dict[str, typing.Any]]] = None,
+        kinesis_stream_props: typing.Optional[aws_cdk.aws_kinesis.StreamProps] = None,
+        logging_bucket_props: typing.Optional[aws_cdk.aws_s3.BucketProps] = None,
+        log_group_props: typing.Optional[aws_cdk.aws_logs.LogGroupProps] = None,
         log_s3_access_logs: typing.Optional[builtins.bool] = None,
     ) -> None:
         '''
@@ -184,26 +166,6 @@ class KinesisStreamsToKinesisFirehoseToS3(
         :since: 1.68.0
         :summary: Constructs a new instance of the KinesisStreamsToKinesisFirehoseToS3 class.
         '''
-        if __debug__:
-            def stub(
-                scope: aws_cdk.core.Construct,
-                id: builtins.str,
-                *,
-                bucket_props: typing.Optional[typing.Union[aws_cdk.aws_s3.BucketProps, typing.Dict[str, typing.Any]]] = None,
-                create_cloud_watch_alarms: typing.Optional[builtins.bool] = None,
-                existing_bucket_obj: typing.Optional[aws_cdk.aws_s3.IBucket] = None,
-                existing_logging_bucket_obj: typing.Optional[aws_cdk.aws_s3.IBucket] = None,
-                existing_stream_obj: typing.Optional[aws_cdk.aws_kinesis.Stream] = None,
-                kinesis_firehose_props: typing.Any = None,
-                kinesis_stream_props: typing.Optional[typing.Union[aws_cdk.aws_kinesis.StreamProps, typing.Dict[str, typing.Any]]] = None,
-                logging_bucket_props: typing.Optional[typing.Union[aws_cdk.aws_s3.BucketProps, typing.Dict[str, typing.Any]]] = None,
-                log_group_props: typing.Optional[typing.Union[aws_cdk.aws_logs.LogGroupProps, typing.Dict[str, typing.Any]]] = None,
-                log_s3_access_logs: typing.Optional[builtins.bool] = None,
-            ) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
-            check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
-            check_type(argname="argument id", value=id, expected_type=type_hints["id"])
         props = KinesisStreamsToKinesisFirehoseToS3Props(
             bucket_props=bucket_props,
             create_cloud_watch_alarms=create_cloud_watch_alarms,
@@ -219,49 +181,49 @@ class KinesisStreamsToKinesisFirehoseToS3(
 
         jsii.create(self.__class__, self, [scope, id, props])
 
-    @builtins.property
+    @builtins.property # type: ignore[misc]
     @jsii.member(jsii_name="kinesisFirehose")
     def kinesis_firehose(self) -> aws_cdk.aws_kinesisfirehose.CfnDeliveryStream:
         return typing.cast(aws_cdk.aws_kinesisfirehose.CfnDeliveryStream, jsii.get(self, "kinesisFirehose"))
 
-    @builtins.property
+    @builtins.property # type: ignore[misc]
     @jsii.member(jsii_name="kinesisFirehoseLogGroup")
     def kinesis_firehose_log_group(self) -> aws_cdk.aws_logs.LogGroup:
         return typing.cast(aws_cdk.aws_logs.LogGroup, jsii.get(self, "kinesisFirehoseLogGroup"))
 
-    @builtins.property
+    @builtins.property # type: ignore[misc]
     @jsii.member(jsii_name="kinesisFirehoseRole")
     def kinesis_firehose_role(self) -> aws_cdk.aws_iam.Role:
         return typing.cast(aws_cdk.aws_iam.Role, jsii.get(self, "kinesisFirehoseRole"))
 
-    @builtins.property
+    @builtins.property # type: ignore[misc]
     @jsii.member(jsii_name="kinesisStream")
     def kinesis_stream(self) -> aws_cdk.aws_kinesis.Stream:
         return typing.cast(aws_cdk.aws_kinesis.Stream, jsii.get(self, "kinesisStream"))
 
-    @builtins.property
+    @builtins.property # type: ignore[misc]
     @jsii.member(jsii_name="kinesisStreamRole")
     def kinesis_stream_role(self) -> aws_cdk.aws_iam.Role:
         return typing.cast(aws_cdk.aws_iam.Role, jsii.get(self, "kinesisStreamRole"))
 
-    @builtins.property
+    @builtins.property # type: ignore[misc]
     @jsii.member(jsii_name="s3BucketInterface")
     def s3_bucket_interface(self) -> aws_cdk.aws_s3.IBucket:
         return typing.cast(aws_cdk.aws_s3.IBucket, jsii.get(self, "s3BucketInterface"))
 
-    @builtins.property
+    @builtins.property # type: ignore[misc]
     @jsii.member(jsii_name="cloudwatchAlarms")
     def cloudwatch_alarms(
         self,
     ) -> typing.Optional[typing.List[aws_cdk.aws_cloudwatch.Alarm]]:
         return typing.cast(typing.Optional[typing.List[aws_cdk.aws_cloudwatch.Alarm]], jsii.get(self, "cloudwatchAlarms"))
 
-    @builtins.property
+    @builtins.property # type: ignore[misc]
     @jsii.member(jsii_name="s3Bucket")
     def s3_bucket(self) -> typing.Optional[aws_cdk.aws_s3.Bucket]:
         return typing.cast(typing.Optional[aws_cdk.aws_s3.Bucket], jsii.get(self, "s3Bucket"))
 
-    @builtins.property
+    @builtins.property # type: ignore[misc]
     @jsii.member(jsii_name="s3LoggingBucket")
     def s3_logging_bucket(self) -> typing.Optional[aws_cdk.aws_s3.Bucket]:
         return typing.cast(typing.Optional[aws_cdk.aws_s3.Bucket], jsii.get(self, "s3LoggingBucket"))
@@ -287,15 +249,15 @@ class KinesisStreamsToKinesisFirehoseToS3Props:
     def __init__(
         self,
         *,
-        bucket_props: typing.Optional[typing.Union[aws_cdk.aws_s3.BucketProps, typing.Dict[str, typing.Any]]] = None,
+        bucket_props: typing.Optional[aws_cdk.aws_s3.BucketProps] = None,
         create_cloud_watch_alarms: typing.Optional[builtins.bool] = None,
         existing_bucket_obj: typing.Optional[aws_cdk.aws_s3.IBucket] = None,
         existing_logging_bucket_obj: typing.Optional[aws_cdk.aws_s3.IBucket] = None,
         existing_stream_obj: typing.Optional[aws_cdk.aws_kinesis.Stream] = None,
         kinesis_firehose_props: typing.Any = None,
-        kinesis_stream_props: typing.Optional[typing.Union[aws_cdk.aws_kinesis.StreamProps, typing.Dict[str, typing.Any]]] = None,
-        logging_bucket_props: typing.Optional[typing.Union[aws_cdk.aws_s3.BucketProps, typing.Dict[str, typing.Any]]] = None,
-        log_group_props: typing.Optional[typing.Union[aws_cdk.aws_logs.LogGroupProps, typing.Dict[str, typing.Any]]] = None,
+        kinesis_stream_props: typing.Optional[aws_cdk.aws_kinesis.StreamProps] = None,
+        logging_bucket_props: typing.Optional[aws_cdk.aws_s3.BucketProps] = None,
+        log_group_props: typing.Optional[aws_cdk.aws_logs.LogGroupProps] = None,
         log_s3_access_logs: typing.Optional[builtins.bool] = None,
     ) -> None:
         '''The properties for the KinesisStreamsToKinesisFirehoseToS3 class.
@@ -319,32 +281,6 @@ class KinesisStreamsToKinesisFirehoseToS3Props:
             logging_bucket_props = aws_cdk.aws_s3.BucketProps(**logging_bucket_props)
         if isinstance(log_group_props, dict):
             log_group_props = aws_cdk.aws_logs.LogGroupProps(**log_group_props)
-        if __debug__:
-            def stub(
-                *,
-                bucket_props: typing.Optional[typing.Union[aws_cdk.aws_s3.BucketProps, typing.Dict[str, typing.Any]]] = None,
-                create_cloud_watch_alarms: typing.Optional[builtins.bool] = None,
-                existing_bucket_obj: typing.Optional[aws_cdk.aws_s3.IBucket] = None,
-                existing_logging_bucket_obj: typing.Optional[aws_cdk.aws_s3.IBucket] = None,
-                existing_stream_obj: typing.Optional[aws_cdk.aws_kinesis.Stream] = None,
-                kinesis_firehose_props: typing.Any = None,
-                kinesis_stream_props: typing.Optional[typing.Union[aws_cdk.aws_kinesis.StreamProps, typing.Dict[str, typing.Any]]] = None,
-                logging_bucket_props: typing.Optional[typing.Union[aws_cdk.aws_s3.BucketProps, typing.Dict[str, typing.Any]]] = None,
-                log_group_props: typing.Optional[typing.Union[aws_cdk.aws_logs.LogGroupProps, typing.Dict[str, typing.Any]]] = None,
-                log_s3_access_logs: typing.Optional[builtins.bool] = None,
-            ) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
-            check_type(argname="argument bucket_props", value=bucket_props, expected_type=type_hints["bucket_props"])
-            check_type(argname="argument create_cloud_watch_alarms", value=create_cloud_watch_alarms, expected_type=type_hints["create_cloud_watch_alarms"])
-            check_type(argname="argument existing_bucket_obj", value=existing_bucket_obj, expected_type=type_hints["existing_bucket_obj"])
-            check_type(argname="argument existing_logging_bucket_obj", value=existing_logging_bucket_obj, expected_type=type_hints["existing_logging_bucket_obj"])
-            check_type(argname="argument existing_stream_obj", value=existing_stream_obj, expected_type=type_hints["existing_stream_obj"])
-            check_type(argname="argument kinesis_firehose_props", value=kinesis_firehose_props, expected_type=type_hints["kinesis_firehose_props"])
-            check_type(argname="argument kinesis_stream_props", value=kinesis_stream_props, expected_type=type_hints["kinesis_stream_props"])
-            check_type(argname="argument logging_bucket_props", value=logging_bucket_props, expected_type=type_hints["logging_bucket_props"])
-            check_type(argname="argument log_group_props", value=log_group_props, expected_type=type_hints["log_group_props"])
-            check_type(argname="argument log_s3_access_logs", value=log_s3_access_logs, expected_type=type_hints["log_s3_access_logs"])
         self._values: typing.Dict[str, typing.Any] = {}
         if bucket_props is not None:
             self._values["bucket_props"] = bucket_props
